#!/usr/bin/python

#
# Copyright (C) 2008 by OpenMoko, Inc.
# Written by Marek Lindner <marek@openmoko.com>
# All Rights Reserved
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#

import os


def debug(msg):
	print msg

class wifi_network:
	def __init__(self,wifi_obj, edje_group, uid, snr, secure):
		self.wifi_obj = wifi_obj
		self.uid = uid
		self.snr = snr
		self.secure = secure
		self.edje_group = edje_group

	def init_canvas(self):
		self.canvas_obj = self.wifi_obj.etk_obj.Canvas()
		self.edje_obj = self.wifi_obj.edje(self.wifi_obj.canvas, file=self.wifi_obj.edje_file, group=self.edje_group)
		self.canvas_obj.object_add(self.edje_obj)
		self.edje_obj.calc_force()
		#print "size_get (" + self.uid + "): " + str(self.edje_obj.size_get())
		#print "size_max_get: " + str(self.edje_obj.size_max_get())
		#print "size_min_calc: " + str(self.edje_obj.size_min_calc())
		#print "size_min_get: " + str(self.edje_obj.size_min_get())
		#print dir(self.edje_obj)
		self.edje_obj.size = (440,80)
		self.canvas_obj.size_request_set(self.edje_obj.size[0], self.edje_obj.size[1])
		self.edje_obj.signal_callback_add("mouse,down,1", "*", self.onclick)
		self.edje_obj.show()

		if (self.uid == "wifi_switch"):
			self.edje_obj.part_text_set("wifi-status", self.wifi_obj.enable_str)
		else:
			self.edje_obj.part_text_set("network-name", self.uid)
			self.edje_obj.part_text_set("network-label", str(self.snr) + "%")
			## 1 / float -> set snr
			self.edje_obj.message_send(1, float(self.snr)/100.0)
			## 1 / int -> is secure
			self.edje_obj.message_send(1, self.secure)

	def destroy_canvas(self):
		self.edje_obj.delete()
		self.canvas_obj.destroy()

	def onclick(self, edje_obj, emission, source):
		debug('wifi_clicked: ' + self.uid)
		if (self.uid == "wifi_switch"):
			self.wifi_switch_onclick()

	def wifi_switch_onclick(self):
		debug('wifi_switch_onclick')
		if self.wifi_obj.runnable:
			if (self.wifi_obj.enabled):
				self.wifi_obj.enabled = 0
				self.wifi_obj.enable_str = "off"
				self.wifi_obj.del_all_networks()
			else:
				self.wifi_obj.enabled = 1
				self.wifi_obj.enable_str = "on"
				self.wifi_obj.add_networks()
			self.wifi_obj.redraw_network_list()


class wifi:
	def __init__(self, etk_obj, name="WiFi"):
		self.name = name

		## gui ##
		self.etk_obj = etk_obj
		self.vbox = self.etk_obj.VBox()
		#self.alignment = etk_obj.Alignment()
		#self.alignment.set(1.0, 0.0, 0.0, 0.0)
		#self.alignment.add(self.vbox)
		self.scrolled_view = self.etk_obj.ScrolledView()
		self.scrolled_view.add_with_viewport(self.vbox)
		## hide scrollbars
		self.scrolled_view.policy_set(2, 2)
		#self.scrolled_view.drag_bouncy_set(1)
		#print dir(self.scrolled_view)
		#print "width: " + str(self.scrolled_view.border_width_get())
		#print "color: " + str(self.scrolled_view.color_get())
		#print "geometry: " + str(self.scrolled_view.inner_geometry_get())
		#self.WiFiRenderer = WiFiRenderer(slot=1)
		#self.WiFiRenderer.wifi_obj = self
		#self.WiFiRenderer.init = 0
		#self.item_list = self.etk_obj.ListModel()
		#self.lst = self.etk_obj.List(self.item_list, selectable=True, row_height=80, columns=[(480, self.WiFiRenderer,True)])

		self.network_list = {}
		self.enabled = 0
		self.enable_str = "off"

		## TODO: check for dbus interface
		self.runnable = 1
		#debug("enter init device : " + self.name)

	def init_label(self):
		#debug('init_label')
		self.add_network("wifi_switch", "wifi_switch", "", "")
		self.redraw_network_list()

	def onclick(self):
		#debug('onclick')
		self.edj_object.signal_emit("wifi-slide-in", "exposure")
		self.edj_object.part_text_set("settings-text", "Settings / WiFi")

	def add_networks(self):
		#debug('add_networks')
		for index, item in enumerate([["default", 20, 0], ["John", 80, 0], ["secure", 45, 1]]):
			self.add_network("wifi_item", item[0], item[1], item[2])

	def add_network(self, edje_group, uid, snr, secure):
		#debug('add_network: ' + uid)
		if (uid in self.network_list):
			self.network_list[uid].visible = 1
			return

		self.network_list[uid] = wifi_network(self, edje_group, uid, snr, secure)
		self.network_list[uid].visible = 1

	def del_all_networks(self):
		#debug('del_all_networks')
		for uid, network in self.network_list.iteritems():
			self.del_network(uid, network)

	def del_network(self, uid, network):
		#debug('del_network: ' + str(uid))
		if (uid == "wifi_switch"):
			return

		if not (uid in self.network_list):
			return

		network.edje_obj.delete()
		network.canvas_obj.destroy()
		network.visible = 0

	def redraw_network_list(self):
		#debug('redraw_network_list')
		self.vbox.remove_all()

		for uid, network in sorted(self.network_list.iteritems()):
			if not (network.visible):
				continue

			network.init_canvas()

			## wifi_switch should be the first item
			if (uid == "wifi_switch"):
				self.vbox.insert_at(network.canvas_obj, self.etk_obj.VBox.START, 0, self.etk_obj.VBox.EXPAND_FILL, 0)
			else:
				self.vbox.append(network.canvas_obj, self.etk_obj.VBox.START, self.etk_obj.VBox.EXPAND_FILL, 0)

		self.vbox.show_all()

