#!/usr/bin/python

#
# Copyright (C) 2008 by OpenMoko, Inc.
# Written by Willie Chen <willie_chen@openmoko.com>
#            Marek Lindner <marek@openmoko.com>
# All Rights Reserved
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#


import etk
import edje
import ecore.evas
import sys
#import gobject
#from dbus.mainloop.glib import DBusGMainLoop

from expos import gsm
from expos import bt
from expos import gps
from expos import brightness
from expos import suspend
from expos import time
from expos import sysinfo
from expos import wifi
from expos import profile

#DBusGMainLoop(set_as_default=True)


### TODO ###

## modules ##
# GSM -> needs Qtopia dbus call (holger)
# WiFi -> needs network manager (raster)
# Bluetooth -> DONE
# GPS -> DONE
# Backlight -> DONE
# Suspend -> DONE
# Profile -> DONE
# Time -> DONE
# System Info -> DONE
##

## misc ##
# slow startup because of etk loading
# load backlight settings on boot
##


### load and initialize modules ###

mygsm = gsm()
mybt = bt()
mygps = gps()
mywifi = wifi(etk)
mybrightness = brightness()
mysuspend = suspend()
mytime = time()
mysysinfo = sysinfo(etk)
myprofile = profile()

loaded_modules = [mygsm, mywifi, mybt, mygps, mybrightness, myprofile, mysuspend, mytime, mysysinfo]


### window init ###

def window_delete_request(evas_obj):
	ecore.main_loop_quit()

if ecore.evas.engine_type_supported_get("software_x11_16"):
	window = ecore.evas.SoftwareX11_16(w=480, h=575)
else:
	window = ecore.evas.SoftwareX11(w=480, h=575)

window.callback_delete_request = window_delete_request
window.title = "Exposure"

edje_file="/usr/share/exposure/exposure.edj"
edj=edje.Edje(window.evas, file=edje_file, group="exposure")
edj.size=window.evas.size
window.data["edje"]=edj
edje.frametime_set(1.0/30)

def arrow_clicked(edje_obj, emission, source):
	edj.part_text_set("settings-text", "Settings")

edj.signal_callback_add("mouse,up,1", "arrow-event", arrow_clicked)
edj.show()

mysysinfo.edj_object = edj
mywifi.edj_object = edj
mywifi.edje_file = edje_file
mywifi.edje = edje.Edje
mywifi.canvas = window.evas


### gui setup ###

def clicked(button):
	for module in loaded_modules:
		if str(button).find(module.name) > -1:
			module.onclick()
			break


def label_text(item, status):
	return "<font_size=48>" + item + "<font_size=24>" + '  ' + status

item_list = etk.ListModel()

for index, item in enumerate(loaded_modules):
	item_list.append([item.name, label_text(item.name, "")])
	item.button = item_list[index]
	item.label_text = label_text
	item.timer_add = ecore.timer_add
	item.init_label()

## add empty item so that the last item can scroll into the visible screen
item_list.append(["scroll_helper", ""])

lst = etk.List(item_list, selectable=True, animated_changes=True, row_height=80, columns=[(480, etk.KineticTextRenderer(slot=1, click=clicked),True)])

mainmenu_win = etk.Embed(window.evas)
mainmenu_win.add(lst)
mainmenu_win.show_all()
edj.part_swallow("main-menu", mainmenu_win.object)

sysinfo_win = etk.Embed(window.evas)
sysinfo_win.add(mysysinfo.VBox)
sysinfo_win.show_all()
edj.part_swallow("sysinfo", sysinfo_win.object)

wifi_win = etk.Embed(window.evas)
wifi_win.add(mywifi.scrolled_view)
wifi_win.show_all()
edj.part_swallow("wifi", wifi_win.object)

#def run_dbus_loop():
	#dbus_loop.next()
	#ecore.timer_add(0.25, run_dbus_loop)

#dbus_loop = gobject.MainLoop()
#ecore.timer_add(0.25, run_dbus_loop)

window.show()
ecore.main_loop_begin()

edj.part_unswallow(sysinfo_win.object)
edj.part_unswallow(wifi_win.object)
edj.part_unswallow(mainmenu_win.object)
edj.delete()


